`CLIPTextEncodeFlux` — это продвинутый узел текстового кодирования в ComfyUI, специально разработанный для архитектуры Flux. Он использует механизм двойного кодировщика (CLIP-L и T5XXL) для обработки как структурированных ключевых слов, так и подробных описаний на естественном языке, обеспечивая модели Flux более точное и полное понимание текста для повышения качества генерации изображений по тексту.

Этот узел основан на совместной работе двух кодировщиков:
1. Ввод `clip_l` обрабатывается кодировщиком CLIP-L, который извлекает такие характеристики, как стиль и тема — идеально подходит для кратких описаний.
2. Ввод `t5xxl` обрабатывается кодировщиком T5XXL, который отлично справляется с пониманием сложных и детальных описаний сцен на естественном языке.
3. Результаты обоих кодировщиков объединяются и вместе с параметром `руководство` формируют единое условное представление (`КОНДИЦИОНИРОВАНИЕ`) для последующих узлов выборки Flux, контролируя степень соответствия сгенерированного контента текстовому описанию.

## Входы

| Имя параметра | Тип данных | Способ ввода | Значение по умолчанию | Диапазон | Описание |
|--------------|-----------|--------------|----------------------|----------|----------|
| `clip`       | CLIP      | Вход узла    | Нет                  | -        | Должна быть модель CLIP, поддерживающая архитектуру Flux, включающая кодировщики CLIP-L и T5XXL |
| `clip_l`     | STRING    | Текстовое поле| Нет                  | До 77 токенов | Подходит для кратких описаний ключевых слов, таких как стиль или тема |
| `t5xxl`      | STRING    | Текстовое поле| Нет                  | Практически не ограничено | Подходит для подробных описаний на естественном языке, выражающих сложные сцены и детали |
| `руководство`| FLOAT     | Ползунок     | 3.5                  | 0.0 - 100.0 | Контролирует влияние текстовых условий на процесс генерации; более высокие значения означают более строгое соответствие тексту |

## Выходы

| Имя выхода         | Тип данных     | Описание |
|-------------------|---------------|----------|
| `КОНДИЦИОНИРОВАНИЕ` | CONDITIONING | Содержит объединённые представления обоих кодировщиков и параметр "руководство", используется для условной генерации изображений |

## Примеры использования

### Примеры подсказок

- **Ввод clip_l** (ключевые слова):
  - Используйте структурированные и лаконичные комбинации ключевых слов
  - Пример: `masterpiece, best quality, portrait, oil painting, dramatic lighting`
  - Сфокусируйтесь на стиле, качестве и основной теме

- **Ввод t5xxl** (описание на естественном языке):
  - Используйте полные и плавные описания сцены
  - Пример: `A highly detailed portrait in oil painting style, featuring dramatic chiaroscuro lighting that creates deep shadows and bright highlights, emphasizing the subject's features with renaissance-inspired composition.`
  - Сфокусируйтесь на деталях сцены, пространственных отношениях и световых эффектах

### Примечания

1. Убедитесь, что используете модель CLIP, совместимую с архитектурой Flux
2. Рекомендуется заполнять оба поля: `clip_l` и `t5xxl`, чтобы использовать преимущества двойного кодировщика
3. Обратите внимание на ограничение в 77 токенов для `clip_l`
4. Регулируйте параметр `руководство` в зависимости от получаемых результатов
